OC.L10N.register(
    "files_trashbin",
    {
    "Deleted files" : "Archivos borrados",
    "restored" : "recuperado",
    "Restore" : "Recuperar",
    "Delete permanently" : "Borrar permanentemente",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio no está disponible, compruebe los registros o póngase en contacto con el administrador",
    "No deleted files" : "No hay archivos eliminados",
    "You will be able to recover deleted files from here" : "Podrás recuperar archivos eliminados desde aquí",
    "No entries found in this folder" : "No se encontraron entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Delete" : "Borrar"
},
"nplurals=2; plural=(n != 1);");
